yakumo.neutron.v2.lbaas.listener

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module listener |
[hide private]
[frames] | no frames]

# Module listener

source code

Resource class and its manager for LBaaS listeners in Networking V2 API

Classes | [hide private]
| Resource Resource class for LBaaS listeners in Networking V2 API
| Manager Manager class for LBaaS listeners in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lbaas``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('protocol', 'protocol', mapper.Noop
      ), ('protocol_port', 'protocol_port', mapper.Noop), ('connection_limit
      ', 'connection_limit', mapper.Noop), ('default_tls_container_ref', 'de
      fault_tls_container_ref', mapper.Noop), ('sni_container_refs', 'sni_co
      ntainer_refs', mapper.Noop), ('default_pool', 'default_pool_id', mappe
      r.Resource('neutron.lbaas.pool')), ('project', 'tenant_id', mapper.Res
      ource('project')), ('is_enabled', 'admin_state_up', mapper.Noop),]